/* edit-clue-info.c
 *
 * Copyright 2023 Jonathan Blandford
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "crosswords-config.h"
#include <libipuz/libipuz.h>
#include <glib/gi18n-lib.h>
#include "edit-clue-info.h"
#include "word-list-model.h"


struct _EditClueInfo
{
  GtkWidget parent_instance;
  GtkWidget *flow_box;
  WordListModel *word_list_model;
};


G_DEFINE_FINAL_TYPE (EditClueInfo, edit_clue_info, GTK_TYPE_WIDGET);


static void edit_clue_info_init       (EditClueInfo      *self);
static void edit_clue_info_class_init (EditClueInfoClass *klass);


static void
edit_clue_info_class_init (EditClueInfoClass *klass)
{
  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);

  gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/Crosswords/edit-clue-info.ui");

  gtk_widget_class_bind_template_child (widget_class, EditClueInfo, flow_box);
  gtk_widget_class_bind_template_child (widget_class, EditClueInfo, word_list_model);

  gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BOX_LAYOUT);
}

static void
row_changed_cb (GtkWidget        *label,
                WordListModelRow *row)
{
  gtk_label_set_text (GTK_LABEL (label),
                      word_list_model_row_get_word (row));
}

GtkWidget *
create_widget_func (GObject  *item,
                    gpointer  user_data)
{
  GtkWidget *label;
  const gchar *word;

  word = word_list_model_row_get_word (WORD_LIST_MODEL_ROW (item));
  label = gtk_label_new (word);
  g_signal_connect_swapped (item, "changed", G_CALLBACK (row_changed_cb), label);

  return label;
}

static void
edit_clue_info_init (EditClueInfo *self)
{
  gtk_widget_init_template (GTK_WIDGET (self));
  gtk_flow_box_bind_model (GTK_FLOW_BOX (self->flow_box),
                           G_LIST_MODEL (self->word_list_model),
                           (GtkFlowBoxCreateWidgetFunc) create_widget_func,
                           NULL, NULL);
}

/* Public methods */

void
edit_clue_info_update (EditClueInfo *self,
                       const gchar  *selection_text)
{
  WordListMode mode = WORD_LIST_ANAGRAM;

  for (const gchar *p = selection_text;
       p[0];
       p = g_utf8_next_char (p))
    {
      if (p[0] == '?')
        {
          mode = WORD_LIST_MATCH;
          break;
        }
    }

  if (mode == WORD_LIST_ANAGRAM)
    word_list_model_set_filter (WORD_LIST_MODEL (self->word_list_model),
                                selection_text,
                                mode);
  else
    word_list_model_set_filter (WORD_LIST_MODEL (self->word_list_model),
                                "",
                                mode);

}
